==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/hu/settings.php <==
<?php

return [
    '1 month' => '1 hónap',
    '1 week' => '1 hét',
    '1 year' => '1 év',
    '2 weeks' => '2 hét',
    '3 months' => '3 hónap',
    '6 months' => '6 hónap',
    '<strong>Confirm</strong> icon deletion' => 'Ikon törlés <strong>megerősítése</strong>',
    '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
    '<strong>Maintenance</strong> Mode' => '<strong>Karbantartás</strong> mód',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Figyelem:</strong> Az összes felhasználót azonnal kijelentkeztetjük, kivéve az adminokat.',
    'APC(u)' => 'APC(u)',
    'Activate' => 'Bekapcsolás',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Bekapcsolja a karbantartási módot, és letiltja a platformhoz való hozzáférést nem adminisztrátorok számára?<br><br>',
    'Add OEmbed provider' => 'OEmbed szolgáltató hozzáadása',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Adjon hozzá egyedi információs szöveget a karbantartási módhoz. Meg fog jelenni a bejelentkezési oldalon.',
    'Add new provider' => 'Új szolgáltató hozzáadása',
    'Advanced Settings' => 'Speciális beállítások',
    'Allow Self-Signed Certificates?' => 'Önaláírt tanúsítványok elfogasása?',
    'Allowed file extensions' => 'Engedélyezett fájlkiterjesztések',
    'Alphabetical' => 'ABC sorrend',
    'Appearance Settings' => 'Megjelenítési beállítások',
    'Auto format based on user language - Example: {example}' => 'Automatikus formátum a felhasználói nyelv alapján - Példa: {example}',
    'Back to overview' => 'Vissza az áttekintéshez',
    'Base URL' => 'Alap URL',
    'Cache Backend' => 'Gyorsítótár backend',
    'Comma separated list. Leave empty to allow all.' => 'Vesszővel elválasztott lista. Hagyd üresen, ha az összeset engedélyezni akarod.',
    'Could not send test email.' => 'Nem sikerült elküldeni a teszt e-mailt.',
    'Currently no provider active!' => 'Jelenleg egyetlen szolgáltató sem aktív!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Jelenleg {count} rekord szerepel az adatbázisban, ami ekkor lett létrehozva: {dating}.',
    'Dashboard' => 'Vezérlőpult',
    'Date input format' => 'Dátum beviteli formátuma',
    'Deactivate' => 'Kikapcsolás',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Kikapcsolja a karbantartási módot, és minden felhasználó számára lehetővé teszi a platform újbóli elérését?',
    'Default Expire Time (in seconds)' => 'Alapértelmezett lejárati idő (másodpercekben)',
    'Default Timezone' => 'Alapértelmezett időzóna',
    'Default language' => 'Alapértelmezett nyelv',
    'Default pagination size (Entries per page)' => 'Alapértelmezett lapozásméret (oldalankénti bejegyzések)',
    'Default stream content order' => 'A stream tartalmának alapértelmezett sorrendje',
    'Delete' => 'Törlés',
    'Display Name (Format)' => 'Megjelenítési név (formátum)',
    'Dropdown space order' => 'Legördülő közösségek sorrendje',
    'E-Mail' => 'E-mail',
    'E-Mail sender address' => 'E-mail küldőjének címe',
    'E-Mail sender name' => 'E-mail küldőjének neve',
    'E.g. http://example.com/humhub' => 'Pl.: http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbed szolgáltató szerkesztése',
    'Enable maintenance mode' => 'Karbantartási mód engedélyezése',
    'Enable user friendship system' => 'Felhasználók barátkozásának engedélyezése',
    'Enabled' => 'Bekapcsolva',
    'Enabled OEmbed providers' => 'Engedélyezett OEmbed szolgáltatók',
    'Encryption' => 'Titkosítás',
    'Endpoint Url' => 'Végpont URL',
    'Exclude media files from stream attachment list' => 'Médiafájlok kizárása az adatfolyam mellékletek listájából',
    'File' => 'Fájl',
    'Firstname Lastname (e.g. John Doe)' => 'Utónév Vezetéknév (pl.: János Kovács)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Fix formátum (nn/hh/éééé) - Példa: {example}',
    'Friendship' => 'Ismerősök',
    'General' => 'Általános',
    'General Settings' => 'Általános beállítások',
    'HTML tracking code' => 'HTML-követőkód',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod regisztrálói viselkedéssel kapcsolatos beállításait és további felhasználói beállításokat.',
    'Here you can configure basic settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod alapbeállításait.',
    'Horizontal scrolling images on a mobile device' => 'Vízszintes görgetési képek mobileszközön',
    'Icon upload' => 'Ikon feltöltés',
    'Last visit' => 'Utolsó látogatás',
    'Logo upload' => 'Logo feltöltés',
    'Mail Transport Type' => 'Levélszállítás típusa',
    'Maintenance mode' => 'Karbantartás mód',
    'Maximum allowed age for logs.' => 'A naplózott fájlok maximális megengedett kora.',
    'Maximum upload file size (in MB)' => 'Legnagyobb feltöltési fájlméret (MB)',
    'Mobile appearance' => 'Mobil megjelenés',
    'Name of the application' => 'Az alkamazás neve',
    'No Proxy Hosts' => 'Nincsenek proxy hosztok',
    'No caching' => 'Nincs gyorsítótárazás',
    'Notification Settings' => 'Értesítési beállítások',
    'Old logs can significantly increase the size of your database while providing little information.' => 'A régi log fájlok jelentősen növelhetik az adatbázis méretét, miközben kevés információt nyújtanak.',
    'PHP APC(u) Extension missing - Type not available!' => 'Hiányzó PHP APC(u) kiterjesztés - A típus nem elérhető!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'A PHP maximum {maxUploadSize} MB-t jelentett',
    'Password' => 'Jelszó',
    'Port' => 'Port',
    'Port number' => 'Portszám',
    'Prevent client caching of following scripts' => 'A következő szkriptek ügyfél gyorsítótárazásának megakadályozása',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => 'Jelentett adatbázis ideje: {dateTime}',
    'SMTP Options' => 'SMTP opciók',
    'Save' => 'Mentés',
    'Save & Flush Caches' => 'Mentés és gyorsítótárak ürítése',
    'Save & Test' => 'Mentés és tesztelés',
    'Saved' => 'Mentve',
    'Saved and flushed cache' => 'Mentve és gyorsítótár törölve',
    'Saved and sent test email to: {address}' => 'Mentett és elküldött teszt e-mailt a következő címre: {address}',
    'Server' => 'Szerver',
    'Server Timezone' => 'Szerver időzónája',
    'Show introduction tour for new users' => 'Oktató rész mutatása új felhasználóknak',
    'Show user profile post form on dashboard' => 'Felhasználói profil közzétételi űrlapjának megjelenítése az áttekintésben',
    'Sort by creation date' => 'Rendezés a létrehozás dátuma szerint',
    'Sort by update date' => 'Rendezés a frissítés dátuma szerint',
    'Test message' => 'Tesztüzenet',
    'Theme' => 'Téma',
    'These settings refer to advanced topics of your social network.' => 'Ezek a beállítások közösségi hálózatod speciális témáira vonatkoznak.',
    'These settings refer to the appearance of your social network.' => 'Ezek a beállítások közösségi hálózatod megjelenésére vonatkoznak.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Használja a %url% címet helykitöltőnek az URL-hez. A formátumnak a következőnek kell lennie: JSON. (pl. http://www.youtube.com/oembed?url=%url%&amp;format=json))',
    'Use X-Sendfile for File Downloads' => 'Az X-Sendfile használata fájlok letöltéséhez',
    'Use the default swipe to show sidebar on a mobile device' => 'Az alapértelmezett csúsztatással jelenítse meg az oldalsávot egy mobil eszközön',
    'User' => 'Felhasználó',
    'User Settings' => 'Felhasználói beállítások',
    'Username' => 'Felhasználónév',
    'Username (e.g. john)' => 'Felhasználónév (pl.: janos)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Hozzáadhatsz egy statisztikai HTML kódrészletet - amely minden renderelt oldalhoz hozzáadódik.',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Jelenleg egyetlen ikont sem használsz. Töltsd fel most a logót.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Jelenleg nem használsz logót. Töltsd fel logódat most.',
    'never' => 'soha',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/hu/settings.php <==
<?php

return [
    '1 month' => '1 hónap',
    '1 week' => '1 hét',
    '1 year' => '1 év',
    '2 weeks' => '2 hét',
    '3 months' => '3 hónap',
    '6 months' => '6 hónap',
    '<strong>Confirm</strong> icon deletion' => 'Ikon törlés <strong>megerősítése</strong>',
    '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
    '<strong>Maintenance</strong> Mode' => '<strong>Karbantartás</strong> mód',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Figyelem:</strong> Az összes felhasználót azonnal kijelentkeztetjük, kivéve az adminokat.',
    'Access Token' => 'Hozzáférési token',
    'Access token is not provided yet.' => 'Hozzáférési token még nincs megadva.',
    'Activate' => 'Bekapcsolás',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Bekapcsolja a karbantartási módot, és letiltja a platformhoz való hozzáférést nem adminisztrátorok számára?<br><br>',
    'Add OEmbed provider' => 'OEmbed szolgáltató hozzáadása',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Adjon hozzá egyedi információs szöveget a karbantartási módhoz. Meg fog jelenni a bejelentkezési oldalon.',
    'Add new provider' => 'Új szolgáltató hozzáadása',
    'Advanced Settings' => 'Speciális beállítások',
    'Allow Self-Signed Certificates?' => 'Önaláírt tanúsítványok elfogasása?',
    'Allowed file extensions' => 'Engedélyezett fájlkiterjesztések',
    'Alphabetical' => 'ABC sorrend',
    'Appearance Settings' => 'Megjelenítési beállítások',
    'Auto format based on user language - Example: {example}' => 'Automatikus formátum a felhasználói nyelv alapján - Példa: {example}',
    'Back to overview' => 'Vissza az áttekintéshez',
    'Base URL' => 'Alap URL',
    'Comma separated list. Leave empty to allow all.' => 'Vesszővel elválasztott lista. Hagyd üresen, ha az összeset engedélyezni akarod.',
    'Configuration (Use settings from configuration file)' => 'Konfiguráció (Használja a konfigurációs fájl beállításait)',
    'Could not send test email.' => 'Nem sikerült elküldeni a teszt e-mailt.',
    'Currently no provider active!' => 'Jelenleg egyetlen szolgáltató sem aktív!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Jelenleg {count} rekord szerepel az adatbázisban, ami ekkor lett létrehozva: {dating}.',
    'Custom DSN' => 'Egyedi DSN',
    'DSN' => 'DSN',
    'DSN Examples:' => 'DSN példák:',
    'Dashboard' => 'Vezérlőpult',
    'Date input format' => 'Dátum beviteli formátuma',
    'Deactivate' => 'Kikapcsolás',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Kikapcsolja a karbantartási módot, és minden felhasználó számára lehetővé teszi a platform újbóli elérését?',
    'Default Timezone' => 'Alapértelmezett időzóna',
    'Default language' => 'Alapértelmezett nyelv',
    'Default pagination size (Entries per page)' => 'Alapértelmezett lapozásméret (oldalankénti bejegyzések)',
    'Default stream content order' => 'A stream tartalmának alapértelmezett sorrendje',
    'Delete' => 'Törlés',
    'Dropdown space order' => 'Legördülő közösségek sorrendje',
    'E-Mail' => 'E-mail',
    'E-Mail reply-to' => 'Válasz e-mail címre',
    'E-Mail sender address' => 'E-mail küldőjének címe',
    'E-Mail sender name' => 'E-mail küldőjének neve',
    'E.g. http://example.com/humhub' => 'Pl.: http://example.com/humhub',
    'Edit OEmbed provider' => 'OEmbed szolgáltató szerkesztése',
    'Embedded content requires the user\'s consent to be loaded' => 'A beágyazott tartalom betöltéséhez a felhasználó beleegyezése szükséges',
    'Enable maintenance mode' => 'Karbantartási mód engedélyezése',
    'Enable user friendship system' => 'Felhasználók barátkozásának engedélyezése',
    'Enabled' => 'Bekapcsolva',
    'Enabled OEmbed providers' => 'Engedélyezett OEmbed szolgáltatók',
    'Endpoint Url' => 'Végpont URL',
    'Exclude media files from stream attachment list' => 'Médiafájlok kizárása az adatfolyam mellékletek listájából',
    'Firstname Lastname (e.g. John Doe)' => 'Utónév Vezetéknév (pl.: János Kovács)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Fix formátum (nn/hh/éééé) - Példa: {example}',
    'Friendship' => 'Ismerősök',
    'General' => 'Általános',
    'General Settings' => 'Általános beállítások',
    'HTML tracking code' => 'HTML-követőkód',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod regisztrálói viselkedéssel kapcsolatos beállításait és további felhasználói beállításokat.',
    'Here you can configure basic settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod alapbeállításait.',
    'Horizontal scrolling images on a mobile device' => 'Vízszintes görgetési képek mobileszközön',
    'Icon upload' => 'Ikon feltöltés',
    'Last visit' => 'Utolsó látogatás',
    'Logo upload' => 'Logo feltöltés',
    'Mail Transport Type' => 'Levélszállítás típusa',
    'Maintenance mode' => 'Karbantartás mód',
    'Maximum allowed age for logs.' => 'A naplózott fájlok maximális megengedett kora.',
    'Maximum upload file size (in MB)' => 'Legnagyobb feltöltési fájlméret (MB)',
    'Mobile appearance' => 'Mobil megjelenés',
    'Name of the application' => 'Az alkamazás neve',
    'No Delivery (Debug Mode, Save as file)' => 'Nincs kézbesítés (Hibakeresési mód, Mentés fájlként)',
    'No Proxy Hosts' => 'Nincsenek proxy hosztok',
    'Notification Settings' => 'Értesítési beállítások',
    'Old logs can significantly increase the size of your database while providing little information.' => 'A régi log fájlok jelentősen növelhetik az adatbázis méretét, miközben kevés információt nyújtanak.',
    'Optional. Default reply address for system emails like notifications.' => 'Választható. Alapértelmezett válaszcím a rendszer e-mailjeihez, például az értesítésekhez.',
    'PHP (Use settings of php.ini file)' => 'PHP (Használja a php.ini fájl beállításait)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'A PHP maximum {maxUploadSize} MB-t jelentett',
    'Password' => 'Jelszó',
    'Port' => 'Port',
    'Port number' => 'Portszám',
    'Provider Name' => 'Szolgáltató neve',
    'Regular expression by which the link match will be checked.' => 'Reguláris kifejezés, amellyel a hivatkozás egyezését ellenőrzi.',
    'Reported database time: {dateTime}' => 'Jelentett adatbázis ideje: {dateTime}',
    'Save' => 'Mentés',
    'Save & Flush Caches' => 'Mentés és gyorsítótárak ürítése',
    'Save & Test' => 'Mentés és tesztelés',
    'Saved' => 'Mentve',
    'Saved and flushed cache' => 'Mentve és gyorsítótár törölve',
    'Saved and sent test email to: {address}' => 'Mentett és elküldött teszt e-mailt a következő címre: {address}',
    'Server' => 'Szerver',
    'Server Timezone' => 'Szerver időzónája',
    'Show introduction tour for new users' => 'Oktató rész mutatása új felhasználóknak',
    'Show user profile post form on dashboard' => 'Felhasználói profil közzétételi űrlapjának megjelenítése az áttekintésben',
    'Sort by creation date' => 'Rendezés a létrehozás dátuma szerint',
    'Sort by update date' => 'Rendezés a frissítés dátuma szerint',
    'Test message' => 'Tesztüzenet',
    'Theme' => 'Téma',
    'These settings refer to advanced topics of your social network.' => 'Ezek a beállítások közösségi hálózatod speciális témáira vonatkoznak.',
    'These settings refer to the appearance of your social network.' => 'Ezek a beállítások közösségi hálózatod megjelenésére vonatkoznak.',
    'Url Pattern' => 'URL-minta',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Használja a %url% címet helykitöltőnek az URL-hez. A formátumnak a következőnek kell lennie: JSON. (pl. http://www.youtube.com/oembed?url=%url%&amp;format=json))',
    'Use SMTPS' => 'SMTPS használata',
    'Use X-Sendfile for File Downloads' => 'Az X-Sendfile használata fájlok letöltéséhez',
    'User' => 'Felhasználó',
    'User Display Name' => 'Felhasználó megjelenített név',
    'User Display Name Subtitle' => 'Felhasználó megjelenített név Felirat',
    'User Settings' => 'Felhasználói beállítások',
    'Username' => 'Felhasználónév',
    'Username (e.g. john)' => 'Felhasználónév (pl.: janos)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Hozzáadhatsz egy statisztikai HTML kódrészletet - amely minden renderelt oldalhoz hozzáadódik.',
    'You can find more configuration options here:' => 'További konfigurációs lehetőségeket itt találsz:',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Jelenleg egyetlen ikont sem használsz. Töltsd fel most a logót.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Jelenleg nem használsz logót. Töltsd fel logódat most.',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => 'pl. 25 (SMTP-hez) vagy 465 (SMTPS-hez)',
    'e.g. localhost' => 'pl. helyi kiszolgáló',
    'e.g. smtps://user:pass@smtp.example.com:port' => 'pl. smtps://user:pass@smtp.example.com:port',
    'never' => 'soha',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
